"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var ts = require("typescript");
var sourceFile_1 = require("../sourceFile");
var defaultOptions = {
    target: ts.ScriptTarget.Latest,
    module: ts.ModuleKind.CommonJS
};
describe('sourceFile', function () {
    var fileName = path.join(__dirname, '../../src/__tests__/data/SourceFile.tsx'); // it's running in ./temp
    var program = ts.createProgram([fileName], defaultOptions);
    var checker = program.getTypeChecker();
    var sourceFile = program.getSourceFile(fileName);
    var target = new sourceFile_1.SourceFile(sourceFile, checker);
    it("should provide data about variables", function () {
        var result = target.variables;
        chai_1.assert.equal(result.length, 4);
        var r1 = result[0];
        chai_1.assert.equal(r1.name, "unexportedVar");
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.equal(r1.kind, "literal");
        chai_1.assert.equal(r1.initializerFlags, ts.TypeFlags.NumberLiteral);
        var r2 = result[1];
        chai_1.assert.equal(r2.name, "exportedVar");
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.equal(r2.kind, "literal");
        chai_1.assert.equal(r2.initializerFlags, ts.TypeFlags.NumberLiteral);
        var r3 = result[2];
        chai_1.assert.equal(r3.name, "unexportedVarFunction");
        chai_1.assert.equal(r3.exported, false);
        chai_1.assert.equal(r3.kind, "arrowFunction");
        chai_1.assert.equal(r3.arrowFunctionType, "number");
        chai_1.assert.deepEqual(r3.arrowFunctionParams, ["string"]);
        var r4 = result[3];
        chai_1.assert.equal(r4.name, "exportedVarFunction");
        chai_1.assert.equal(r4.exported, true);
        chai_1.assert.equal(r4.kind, "arrowFunction");
        chai_1.assert.equal(r4.arrowFunctionType, "string");
        chai_1.assert.deepEqual(r4.arrowFunctionParams, ["number", "string"]);
    });
    it("should provide data about interfaces", function () {
        var result = target.interfaces;
        chai_1.assert.equal(result.length, 2);
        var r1 = result[0];
        chai_1.assert.equal(r1.name, "UnexportedInterface");
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.deepEqual(r1.properties, [{
                "name": "prop1",
                "text": "prop1: string;",
                "type": "string",
                "isRequired": true,
                "comment": "prop1 comment",
                "values": [],
            }]);
        var r2 = result[1];
        chai_1.assert.equal(r2.name, "ExportedInterface");
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.deepEqual(r2.properties, [{
                "name": "prop1",
                "text": "prop1: string;",
                "type": "string",
                "isRequired": true,
                "comment": "prop1 comment",
                "values": [],
            }, {
                "name": "prop2",
                "text": "prop2: string;",
                "type": "string",
                "isRequired": true,
                "comment": "prop2 comment",
                "values": [],
            }]);
    });
    it("should provide data about classes", function () {
        var result = target.classes;
        chai_1.assert.equal(result.length, 2);
        var r1 = result[0];
        chai_1.assert.equal(r1.name, "UnexportedClass");
        chai_1.assert.equal(r1.exported, false);
        chai_1.assert.deepEqual(r1.methods, [{ name: "method1" }]);
        var r2 = result[1];
        chai_1.assert.equal(r2.name, "ExportedClass");
        chai_1.assert.equal(r2.exported, true);
        chai_1.assert.deepEqual(r2.methods, [{ name: "method1" }, { name: "method2" }]);
    });
});
//# sourceMappingURL=sourceFile.spec.js.map